@@ -11,27 +11,34 @@ DELIMITER = '\t'
 ENCODING = 'ISO-8859-1'
 GLOSSARY_FOLDER = 'glossary/lookups'
 _memory = {}
+MISSING_VALUE = '-'
 MISSING = -99999
 
 
-def _is_missing_value(value): return value == MISSING
+def _is_missing_value(value): return value == MISSING_VALUE or value == MISSING or value == str(MISSING)
+
+
+def _replace_missing_values(value: str):
+    value = value.replace(f"{DELIMITER}{MISSING_VALUE}", f"{DELIMITER}{MISSING}")
+    # handle missing value at begining of the row
+    return value.replace(MISSING_VALUE, str(MISSING), 1) if value.startswith(MISSING_VALUE) else value
 
 
 def _rewrite_csv_file_as_tab(filepath: str):
     with open(filepath, 'r', encoding=ENCODING) as fp:
         reader = csv.reader(fp)
         for row in reader:
-            yield DELIMITER.join(row)
+            yield _replace_missing_values(DELIMITER.join(row))
 
 
 def _rewrite_csv_text_as_tab(text: str):
     reader = csv.reader(StringIO(text))
     for row in reader:
-        yield DELIMITER.join(row)
+        yield _replace_missing_values(DELIMITER.join(row))
 
 
 def _recfromcsv(data): return numpy.recfromcsv(data,
-                                               missing_values='-',
+                                               missing_values=MISSING_VALUE,
                                                filling_values=MISSING,
                                                delimiter=DELIMITER,
                                                encoding=ENCODING)
@@ -115,7 +122,7 @@ def column_name(key: str):
     str
         The column name that can be used in `get_table_value`.
     """
-    return key.replace(',', '').replace(' ', '_').replace('.', '').replace('-', '').lower()
+    return key.replace(',', '').replace(' ', '_').replace('.', '').replace('-', '').lower() if key else ''
 
 
 def _get_single_table_value(array: numpy.recarray, col_match, col_match_with, col_val):
@@ -209,7 +216,7 @@ def extract_grouped_data_closest_date(data: str, year: int) -> str:
         lambda prev, curr: {
             **prev,
             **{curr.split(':')[0]: curr.split(':')[1]}
-        } if len(curr) > 0 and curr.split(':')[1] != '-' else prev,
+        } if len(curr) > 0 and not _is_missing_value(curr.split(':')[1]) else prev,
         data.split(';'),
         {}
     ) if data is not None and isinstance(data, str) and len(data) > 1 else {}
